@@ -34,19 +34,36 @@ async def create_queues(queues, channel):
     q_conns = {}
     for queue in queues:
         logger.info('Declaring queue: %s', queue['name'])
-        dlq_args = {
+        q_args = {
             **{"x-queue-type": queue.get("type", "quorum")},
             **queue.get("arguments", {})
         }
 
         q_conns[queue['name']] = await channel.declare_queue(
             queue['name'],
-            arguments=dlq_args,
+            arguments=q_args,
             durable=queue.get('durable', True),
             robust=queue.get('robust', True),
             auto_delete=queue.get('auto_delete', False),
             exclusive=queue.get('exclusive', False)
         )
+        dlx_name = queue.get('dlx', f"{queue['name']}_dlx")
+        dlx = await channel.declare_exchange(
+            dlx_name,
+            type=aio_pika.ExchangeType.TOPIC,
+            durable=True,
+            auto_delete=False
+        )
+        dlq_name = queue.get('dlq', f"{queue['name']}_dlq")
+        dlq = await channel.declare_queue(
+            dlq_name,
+            arguments=q_args,
+            durable=True,
+            robust=True,
+            auto_delete=False,
+            exclusive=False
+        )
+        await dlq.bind(dlx_name, routing_key='#')
     return q_conns
 
 
